==> atmsupport-1.0.tar.gz: atmsupport-1.0/libtestlib/testlib.h <==
/*
 * Copyright (c) 2001-2003
 *	Fraunhofer Institute for Open Communication Systems (FhG Fokus).
 * 	All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * Author: Harti Brandt <harti@freebsd.org>
 *
 * $Begemot: atmsupport/libtestlib/testlib.h,v 1.2 2003/08/21 09:14:10 hbb Exp $
 */
#ifndef _NGATM_TESTLIB_H_
#define _NGATM_TESTLIB_H_

#define MAXMSG	(66000)

struct stack {
	enum {
		STACK_END,
		STACK_CONNECT,
		STACK_MKPEER,
	}		op;
	const char	*path;
	const char	*cpath;		/* == type */
	const char	*hook;
	const char	*peerhook;
	const char	*name;
};

void build_stack(int *, int *, const struct stack *);
void shutdown_stack(int, const struct stack *);
void read_cmsg(int csock);

void ev_loop(evContext ctx, int *doprompt, const char *prompt) __dead2;

void dump_hex(u_char *data, size_t n);
void save_data(const char *prefix, const char *type, u_int *filenum,
    const u_char *data, size_t n);
int read_user(char *buf, char **argv);
ssize_t read_file(const char *fn, u_char *buf, size_t buflen);

#endif

==> atmsupport-1.4.tar.gz: atmsupport-1.4/libtestlib/testlib.h <==
/*
 * Copyright (c) 2001-2003
 *	Fraunhofer Institute for Open Communication Systems (FhG Fokus).
 * 	All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * Author: Harti Brandt <harti@freebsd.org>
 *
 * $Begemot: atmsupport/libtestlib/testlib.h,v 1.3 2004/12/20 10:44:57 brandt Exp $
 */
#ifndef _NGATM_TESTLIB_H_
#define _NGATM_TESTLIB_H_

#define MAXMSG	(66000)

struct stack {
	enum {
		STACK_END,
		STACK_CONNECT,
		STACK_MKPEER,
	}		op;
	const char	*path;
	const char	*cpath;		/* == type */
	const char	*hook;
	const char	*peerhook;
	const char	*name;
};

void build_stack(int *, int *, const struct stack *);
void shutdown_stack(int, const struct stack *);
void read_cmsg(int csock);

void ev_loop(int *doprompt, const char *prompt) __dead2;

void dump_hex(u_char *data, size_t n);
void save_data(const char *prefix, const char *type, u_int *filenum,
    const u_char *data, size_t n);
int read_user(char *buf, char **argv);
ssize_t read_file(const char *fn, u_char *buf, size_t buflen);

#endif
